# Exporting Workspace Snapshots
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/exporting-workspace-snapshots#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/exporting-workspace-snapshots#prerequisites)
  * [Step 1: Initiate an Export Job](https://help.sap.com/docs/leanix/ea/exporting-workspace-snapshots#step-1:-initiate-an-export-job)
  * [Step 2: Retrieve a One-Time Download Key](https://help.sap.com/docs/leanix/ea/exporting-workspace-snapshots#step-2:-retrieve-a-one-time-download-key)
  * [Step 3: Retrieve a File with Workspace Data](https://help.sap.com/docs/leanix/ea/exporting-workspace-snapshots#step-3:-retrieve-a-file-with-workspace-data)
  * [Next Steps](https://help.sap.com/docs/leanix/ea/exporting-workspace-snapshots#next-steps)


Export snapshots of your workspace data through the Pathfinder REST API.
